@@ -287,6 +287,38 @@ class Logger(object):
                 fb = f.read(BLOCK_SIZE) # Read the next block from the file
         return file_hash.hexdigest() # Get the hexadecimal digest of the hash
 
+    def _get_program_file(self):
+        try: #If the program is run from a script
+            return __main__.__file__
+        except AttributeError: 
+            #there might be more options to try
+            #see: https://stackoverflow.com/a/35514032
+            return None
+    
+    def _to_string(self, accessed_only=False):
+        lines=[]
+        lines.append("<Date> "+str(datetime.datetime.now()))
+        lines.append("<Program> "+str(self._get_program_file()))
+        lines.append("<Arguments> "+str(sys.argv[1:]))
+        lines.append("<Version> "+str(self.version))
+        lines.append("<Input> "+str(self.filename))
+        lines.append("<Runtime> "+str(datetime.datetime.now()-self.creation_date))
+        lines.append("**************************")
+        if accessed_only:
+            log_options_dict=self.get_accessed_options()
+        else:
+            log_options_dict=self.options.to_leafdict()
+        log_options_str=json.dumps(log_options_dict, indent=4, default=str)       
+        lines+=[line for line in log_options_str.split("\n")]
+        if len(self.outfilenames)>0:
+            lines.append("**************************")
+            lines.append("Output files created:")
+            for path in self.outfilenames:
+                lines.append("<PATH> "+str(path))
+                lines.append("<HASH> "+self.hash_file(path))
+        lines=[l+"\n" for l in lines]
+        return lines
+
     def _create_log_txt(self, accessed_only=False):
         """
         Create a log in text format
@@ -304,25 +336,9 @@ class Logger(object):
         log=[]
         log.append("cd "+os.getcwd())
         log.append("python3 "+" ".join(sys.argv))
-        log.append("# <Date> "+str(datetime.datetime.now()))
-        log.append("# <Program> "+__main__.__file__)
-        log.append("# <Version> "+str(self.version))
-        log.append("# <Input> "+str(self.filename))
-        log.append("# <Runtime> "+str(datetime.datetime.now()-self.creation_date))
-        log.append("#**************************")
-        if accessed_only:
-            log_options_dict=self.get_accessed_options()
-        else:
-            log_options_dict=self.options.to_leafdict()
-        log_options_str=json.dumps(log_options_dict, indent=4, default=str)       
-        log+=["#" + line for line in log_options_str.split("\n")]
-        if len(self.outfilenames)>0:
-            log.append("#**************************")
-            log.append("#Output files created:")
-            for path in self.outfilenames:
-                log.append("# <PATH> "+str(path))
-                log.append("# <HASH> "+self.hash_file(path))
-        log=[l+"\n" for l in log]
+        lines=self._to_string(accessed_only=accessed_only)
+        lines=['#'+line for line in lines]
+        log.extend(lines)
         return log
     
 
@@ -359,7 +375,7 @@ class Logger(object):
         """
         log={}
         log["date"]=str(datetime.datetime.now())
-        log["program"]=__main__.__file__
+        log["program"]=self._get_program_file()
         log["arguments"]=sys.argv[1:]
         log["version"]=self.version
         log["input"]=str(self.filename)
@@ -373,11 +389,16 @@ class Logger(object):
 
     def show_data(self):
         """Print log."""
-        print(*self._create_log_txt(accessed_only=False))
+        print(*self._to_string(accessed_only=False))
     
     def __str__(self):
         """Get log as string."""
-        return "".join(self._create_log_txt(accessed_only=False))
+        return "".join(self._to_string(accessed_only=False))
+    
+    def __repr__(self):
+        return "".join(self._to_string(accessed_only=False))
+
+
 
     def _write_log_txt(self, new_logs, old_logs, accessed_only=False):
         old_lines=[]
@@ -410,7 +431,25 @@ class Logger(object):
             with open(new, "w") as newfile:
                 json.dump(log_json, newfile, indent=4, default=str)
 
-    def write_log(self, new_logs, old_logs=None, file_ext='log', format='json', accessed_only=True):
+    @classmethod
+    def _get_logfile_name(cls, file, file_ext, ext_modification_mode):
+        if file is None:
+            return []
+        if isinstance(file, str) or isinstance(file, Path):
+            file=[file]
+        file=[Path(p) for p in file]
+        if file_ext!=None:
+            file_ext="."+file_ext.lstrip(".")
+            if ext_modification_mode=='replace':
+                file=[logfile.with_suffix(file_ext) for logfile in file]
+            elif ext_modification_mode=='append':
+                file=[logfile.with_suffix(logfile.suffix+file_ext) for logfile in file]
+            else:
+                raise ValueError(f"Unknown value for 'ext_modification_mode': {ext_modification_mode}")
+        return file
+
+
+    def write_log(self, new_logs, old_logs=None, file_ext='log', ext_modification_mode='append', format='json', accessed_only=True):
         """
         Write log to files.
 
@@ -423,24 +462,24 @@ class Logger(object):
         old_logs : str or Path or iterable of str, Path, optional
             Existing logfiles, listed as dependencies in the new logfiles. (default: None)
         file_ext : str, optional
-            If set, the file extensions in the provided logfile locations are replaced by 'file_ext' before the function is executed. (default: 'log')
+            If set, the file extensions of the provided paths are modified to 'file_ext' before the function is executed. (default: 'log')
+        ext_modification_mode : str, optional
+            How to modify the file extension. Can be 'replace' or 'append'. Only used if 'file_ext' is set. (default: 'append')
         format : str, optional
             Format of the new logfiles. Can be 'json' or 'txt'. (default: 'json')
         accessed_only : bool, optional
             If True, only the options that were accessed are written to the log. (default: True)
         """
-        if isinstance(new_logs, str) or isinstance(new_logs, Path):
-            new_logs=[new_logs]
-        if old_logs is None:
-            old_logs=[]
-        elif isinstance(old_logs, str) or isinstance(old_logs, Path):
-            old_logs=[old_logs]
-        old_logs=[Path(p) for p in old_logs]
-        new_logs=[Path(p) for p in new_logs]
-        if file_ext!=None:
-            file_ext=file_ext.strip(".")
-            old_logs=[logfile.with_suffix("."+file_ext) for logfile in old_logs]
-            new_logs=[logfile.with_suffix("."+file_ext) for logfile in new_logs]
+        new_logs=self._get_logfile_name(new_logs, file_ext, ext_modification_mode)
+        old_logs=self._get_logfile_name(old_logs, file_ext, ext_modification_mode)
+        for i,f in enumerate(old_logs):
+            if not f.exists():
+                old_format=self._get_logfile_name(f.with_suffix(""), file_ext, 'replace')[0]
+                if old_format.exists():
+                    #Deprecation Warning
+                    warnings.warn(f"Logfile {f} does not exist, but {old_format} was found. Will be using this instead. In inlog 2.2.0, the default behaviour changed from replacing file extensions to appending them. To get back the old behaviour, set ext_modification_mode='replace' in write_log().", DeprecationWarning)
+                    old_logs[i]=old_format
+                    
         if format=='json':
             self._write_log_json(new_logs, old_logs, accessed_only)
         elif format=='txt':
